@@ -10,15 +10,15 @@
    Tyrell DarkIce
 
    File     : AlsaDspSource.h
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -66,8 +66,8 @@
 /**
  *  An audio input based on the ALSA sound system 
  *
- *  @author  $Author: darkeye $
- *  @version $Revision: 394 $
+ *  @author  $Author: rafael@riseup.net $
+ *  @version $Revision: 474 $
  */
 class AlsaDspSource : public AudioSource, public virtual Reporter
 {
