@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : AudioSource.cpp
-   Version  : $Revision: 424 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -46,7 +46,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: AudioSource.cpp 424 2008-07-07 14:33:34Z darkeye $";
+static const char fileid[] = "$Id: AudioSource.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
