@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : BufferedSink.cpp
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
      the buffer is filled like this:
@@ -29,7 +29,7 @@
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -68,7 +68,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: BufferedSink.cpp 394 2007-01-14 16:28:42Z darkeye $";
+static const char fileid[] = "$Id: BufferedSink.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
@@ -330,10 +330,15 @@ BufferedSink :: write (    const void    * buf,
 
     // the internal buffer is empty, try to write the fresh data
     soFar = 0;
-    if ( inp != outp ) {
+    if ( inp == outp ) { 
         while ( soFar < len && sink->canWrite( 0, 0) ) {
-            soFar += sink->write( b + soFar, len - soFar);
-        }
+	    try {
+	        soFar += sink->write( b + soFar, len - soFar);
+	    } catch (Exception &e) {
+	        reportEvent(3,"Exception caught in BufferedSink :: write3\n");
+		throw; /* up a level */
+	    }
+	}
     }
     length = soFar;
 
