@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : Connector.cpp
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -41,7 +41,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: Connector.cpp 394 2007-01-14 16:28:42Z darkeye $";
+static const char fileid[] = "$Id: Connector.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
