@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 446 $
-   Author   : $Author: diniz@wimobilis.com.br $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
 
@@ -14,7 +14,7 @@
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -109,7 +109,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp 446 2009-06-21 04:36:30Z diniz@wimobilis.com.br $";
+static const char fileid[] = "$Id: DarkIce.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
 
 
 /*------------------------------------------------------------------------------
