@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : FileSink.h
-   Version  : $Revision: 396 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -51,8 +51,8 @@
 /**
  *  File data output
  *
- *  @author  $Author: darkeye $
- *  @version $Revision: 396 $
+ *  @author  $Author: rafael@riseup.net $
+ *  @version $Revision: 474 $
  */
 class FileSink : public Sink, public virtual Reporter
 {
