@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 446 $
-   Author   : $Author: diniz@wimobilis.com.br $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp 446 2009-06-21 04:36:30Z diniz@wimobilis.com.br $";
+static const char fileid[] = "$Id: IceCast2.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
 
 
 /*------------------------------------------------------------------------------
@@ -190,7 +190,7 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
     }
 
     // send user agent info
-    str = "\nUser-Agent: DarkIce/" VERSION " (http://darkice.tyrell.hu/)";
+    str = "\nUser-Agent: DarkIce/" VERSION " (http://code.google.com/p/darkice/)";
     sink->write( str, strlen( str));
 
     // send the ice- headers
