@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : VorbisLibEncoder.h
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 474 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -52,7 +52,11 @@
 #include "Reporter.h"
 #include "AudioEncoder.h"
 #include "CastSink.h"
+#ifdef HAVE_SRC_LIB
+#include <samplerate.h>
+#else
 #include "aflibConverter.h"
+#endif
 
 
 /* ================================================================ constants */
@@ -67,8 +71,8 @@
  *  A class representing the ogg vorbis encoder linked as a shared object or
  *  as a static library.
  *
- *  @author  $Author: darkeye $
- *  @version $Revision: 394 $
+ *  @author  $Author: rafael@riseup.net $
+ *  @version $Revision: 474 $
  */
 class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
 {
@@ -115,9 +119,14 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
         double                          resampleRatio;
 
         /**
-         *  aflibConverter object for possible resampling
+         *  sample rate converter object for possible resampling
          */
+#ifdef HAVE_SRC_LIB
+        SRC_STATE                     * converter;
+        SRC_DATA                      converterData;
+#else
         aflibConverter                * converter;
+#endif
 
         /**
          *  Initialize the object.
@@ -137,7 +146,13 @@ class VorbisLibEncoder : public AudioEncoder, public virtual Reporter
         strip ( void )                                  throw ( Exception )
         {
             if ( converter ) {
+#ifdef HAVE_SRC_LIB
+                delete [] converterData.data_in;
+                delete [] converterData.data_out;
+                src_delete (converter);
+#else
                 delete converter;
+#endif
             }
         }
 
