@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : main.cpp
-   Version  : $Revision: 394 $
-   Author   : $Author: darkeye $
+   Version  : $Revision: 476 $
+   Author   : $Author: rafael@riseup.net $
    Location : $HeadURL$
    
    Abstract : 
@@ -17,7 +17,7 @@
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -71,7 +71,7 @@ static Ref<DarkIce>     darkice;
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: main.cpp 394 2007-01-14 16:28:42Z darkeye $";
+static const char fileid[] = "$Id: main.cpp 476 2010-05-10 01:30:13Z rafael@riseup.net $";
 
 /*------------------------------------------------------------------------------
  *  Default config file name
@@ -107,9 +107,17 @@ main (
     int     res = -1;
 
     std::cout << "DarkIce " << VERSION
-         << " live audio streamer, http://darkice.tyrell.hu/"
+         << " live audio streamer, http://code.google.com/p/darkice/"
          << std::endl
          << "Copyright (c) 2000-2007, Tyrell Hungary, http://tyrell.hu/"
+         << std::endl
+         << "Copyright (c) 2008-2010, Akos Maroy and Rafael Diniz" 
+         << std::endl
+         << "This is free software, and you are welcome to redistribute it "
+         << std::endl
+	 << "under the terms of The GNU General Public License version 3 or"
+         << std::endl
+	 << "any later version."
          << std::endl << std::endl;
 
     try {
